pub struct CommonHeader {
pub traffic_class: u8,
pub flow_id: u32,
pub next_header: ProtocolNumber,
}Expand description
Represents the common header of a SCION packet
Fields
traffic_class: u8Traffic class of the SCION packet
flow_id: u32Flow ID of the SCION packet
next_header: ProtocolNumberNext header type
Indicates the type of header that follows the SCION header. E.g., UDP, TCP, etc.
Implementations
Sourceimpl CommonHeader
impl CommonHeader
Sourcepub fn valid(&self) -> Result<(), InvalidStructureError>
pub fn valid(&self) -> Result<(), InvalidStructureError>
Validates that all fields in the CommonHeader are valid for encoding
Sourcepub unsafe fn encode_unchecked(
&self,
buf: &mut [u8],
header_len_units: u8,
path_type: PathType,
dst_addr_type: WireHostAddrType,
src_addr_type: WireHostAddrType,
payload_size: u16,
) -> usize
pub unsafe fn encode_unchecked( &self, buf: &mut [u8], header_len_units: u8, path_type: PathType, dst_addr_type: WireHostAddrType, src_addr_type: WireHostAddrType, payload_size: u16, ) -> usize
Encodes the CommonHeader into the provided buffer
Safety
- The implementation may use unchecked indexing operations and relies on the caller to
provide a sufficiently large buffer (at least
CommonHeaderLayout::SIZE_BYTESbytes).