ScionPacketHeader

Struct ScionPacketHeader 

pub struct ScionPacketHeader {
    pub common: CommonHeader,
    pub address: AddressHeader,
    pub path: DpPath,
}
Represents a SCION packet header

This structure contains all the fields of a SCION packet header, including the common header, address header, and path information.

Fields

common: CommonHeader

The common header of the SCION packet

address: AddressHeader

The address header of the SCION packet

path: DpPath

The path information of the SCION packet

Implementations

Source

impl ScionPacketHeader

pub fn required_size(&self) -> usize

Returns the size required for the wire encoding.

Safety

This size must be correct, it is used to validate buffer sizes in encode. If this size is smaller than the actual encoded size, undefined behavior will occur.

pub fn wire_valid(&self) -> Result<(), InvalidStructureError>

Validates that all fields in the structure are valid for encoding.

Note: This only checks the minimal set of fields required for encoding, do not expect comprehensive validation.

Returns Ok(()) if valid, otherwise a static error reference.

pub unsafe fn encode_unchecked( &self, buf: &mut [u8], payload_size: u16, ) -> usize

Writes the wire encoding into the provided buffer.

Returns the number of bytes written.

SAFETY
  1. The buffer must be at least self.required_size() bytes long
  2. The structure must be valid for encoding, i.e., self.valid() must return Ok(())
pub fn try_encode( &self, buf: &mut [u8], payload_size: u16, ) -> Result<usize, EncodeError>

Writes the wire encoding into the provided buffer.

Returns the number of bytes written on success, or Err(usize) of the required size if the buffer is too small or the packet.

The buffer must be at least self.required_size() bytes long.